# FridaDevicesManager

This is a simple tool for managing Frida devices.

## Features

- List all connected devices
- Start a Frida server on a device
- Kill a Frida server on a device

[中文文档](README_CN.md)